@@ -1,9 +1,9 @@
 package Sah::Schema::aohoms;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Collection'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $schema = [array => {
     summary => 'Array of (defined-)hash-of-maybe-strings',
@@ -41,7 +41,7 @@ Sah::Schema::aohoms - Array of (defined-)hash-of-maybe-strings
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::aohoms (from Perl distribution Sah-Schemas-Collection), released on 2020-03-04.
+This document describes version 0.007 of Sah::Schema::aohoms (from Perl distribution Sah-Schemas-Collection), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -55,7 +55,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -77,27 +77,27 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ "a"  # INVALID
 
- undef  # valid
+ []  # valid
 
- undef  # INVALID
+ {}  # INVALID
 
- undef  # INVALID
+ [undef]  # INVALID
 
- undef  # INVALID
+ ["a"]  # INVALID
 
- undef  # INVALID
+ [[]]  # INVALID
 
- undef  # valid
+ [{}]  # valid
 
- undef  # valid
+ [{},{k=>"a"}]  # valid
 
- undef  # INVALID
+ [{},{k=>[]}]  # INVALID
 
- undef  # INVALID
+ [{},{k=>{}}]  # INVALID
 
- undef  # valid
+ [{},{k=>undef}]  # valid
 
 =head1 DESCRIPTION
 
