@@ -1,9 +1,9 @@
 package Sah::Schema::hoaoms;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-04'; # DATE
+our $DATE = '2020-03-08'; # DATE
 our $DIST = 'Sah-Schemas-Collection'; # DIST
-our $VERSION = '0.006'; # VERSION
+our $VERSION = '0.007'; # VERSION
 
 our $schema = [hash => {
     summary => 'Hash of (defined-)array-of-(maybe-)strings',
@@ -41,7 +41,7 @@ Sah::Schema::hoaoms - Hash of (defined-)array-of-(maybe-)strings
 
 =head1 VERSION
 
-This document describes version 0.006 of Sah::Schema::hoaoms (from Perl distribution Sah-Schemas-Collection), released on 2020-03-04.
+This document describes version 0.007 of Sah::Schema::hoaoms (from Perl distribution Sah-Schemas-Collection), released on 2020-03-08.
 
 =head1 SYNOPSIS
 
@@ -55,7 +55,7 @@ Using with L<Data::Sah>:
  # even validators in other languages like JavaScript, from the same schema.
  # See its documentation for more details.
 
-Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
+Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
 
  package MyApp;
  our %SPEC;
@@ -77,27 +77,27 @@ Using in L<Rinci> function metadata (to be used in L<Perinci::CmdLine>, etc):
 
 Sample data:
 
- undef  # INVALID
+ "a"  # INVALID
 
- undef  # INVALID
+ []  # INVALID
 
- undef  # valid
+ {}  # valid
 
- undef  # INVALID
+ {k=>undef}  # INVALID
 
- undef  # INVALID
+ {k=>"a"}  # INVALID
 
- undef  # valid
+ {k=>[]}  # valid
 
- undef  # INVALID
+ {k=>{}}  # INVALID
 
- undef  # valid
+ {k=>[],k2=>["a"]}  # valid
 
- undef  # INVALID
+ {k=>[],k2=>[[]]}  # INVALID
 
- undef  # INVALID
+ {k=>[],k2=>[{}]}  # INVALID
 
- undef  # valid
+ {k=>[],k2=>[undef]}  # valid
 
 =head1 DESCRIPTION
 
